@@ -4,7 +4,7 @@ use warnings;
 use strict;
 
 use vars qw($VERSION @ISA %EXPORT_TAGS @EXPORT @EXPORT_OK);
-$VERSION = '5.18';
+$VERSION = '5.19';
 
 =head1 NAME
 
@@ -94,7 +94,7 @@ Block current request sender IP address.
 =cut
 
 sub BlockIP {
-    my $who     = shift || '';
+    my $who     = shift || 'UNKNOWN';
     my $ipaddr  = shift || return;
 
     if($settings{blockurl}) {
@@ -116,7 +116,7 @@ Allow current request sender IP address.
 =cut
 
 sub AllowIP {
-    my $who     = shift || '';
+    my $who     = shift || 'UNKNOWN';
     my $ipaddr  = shift || return;
 
     if($settings{blockurl}) {
@@ -162,7 +162,7 @@ Miss Barbell Productions, L<http://www.missbarbell.co.uk/>
 
 =head1 COPYRIGHT & LICENSE
 
-  Copyright (C) 2002-2013 Barbie for Miss Barbell Productions
+  Copyright (C) 2002-2014 Barbie for Miss Barbell Productions
   All Rights Reserved.
 
   This module is free software; you can redistribute it and/or
