@@ -4,7 +4,7 @@ use warnings;
 use strict;
 
 use vars qw($VERSION @ISA %EXPORT_TAGS @EXPORT @EXPORT_OK);
-$VERSION = '5.18';
+$VERSION = '5.19';
 
 =head1 NAME
 
@@ -104,7 +104,7 @@ sub MetaSearch {
     return ()   unless(@$keys && $meta);
 
     my $where = $hash{'where'} ? "AND $hash{'where'}" : '';
-    my $limit = $hash{'limit'} ? "LIMIT=$hash{'limit'}" : '';
+    my $limit = $hash{'limit'} ? "LIMIT $hash{'limit'}" : '';
     my $order = $hash{'order'} ? "ORDER BY $hash{'order'}" : '';
 
     my %res;
@@ -221,7 +221,7 @@ Miss Barbell Productions, L<http://www.missbarbell.co.uk/>
 
 =head1 COPYRIGHT & LICENSE
 
-  Copyright (C) 2002-2013 Barbie for Miss Barbell Productions
+  Copyright (C) 2002-2014 Barbie for Miss Barbell Productions
   All Rights Reserved.
 
   This module is free software; you can redistribute it and/or
