@@ -4,7 +4,7 @@ use warnings;
 use strict;
 
 use vars qw($VERSION @ISA @EXPORT @EXPORT_OK);
-$VERSION = '5.18';
+$VERSION = '5.19';
 
 =head1 NAME
 
@@ -149,7 +149,7 @@ sub Publish {
     Config()    unless($PARSER && $RENDER);
 
     # redirects require minimal processing
-    if($tvars{redirect}) {
+    if($tvars{redirect} && $tvars{redirect} ne $tvars{request}) {
         $RENDER->redirect($tvars{redirect});
         $published = 1;
         return;
@@ -163,7 +163,7 @@ sub Publish {
         return;
     }
 
-    my $path = $settings{'templates'};
+    my $path = $settings{'templates'} || '';
     my $vars = \%tvars;
 
     unless($vars->{'layout'} && -r "$path/$vars->{'layout'}") {
@@ -290,7 +290,7 @@ Miss Barbell Productions, L<http://www.missbarbell.co.uk/>
 
 =head1 COPYRIGHT & LICENSE
 
-  Copyright (C) 2002-2013 Barbie for Miss Barbell Productions
+  Copyright (C) 2002-2014 Barbie for Miss Barbell Productions
   All Rights Reserved.
 
   This module is free software; you can redistribute it and/or
